var gtxmcperm = function ($, settings) {
	var folders, // channel folders 
		$store = $('input[name=f_node_restriction]'), // location to write json data to
		nodeRestriction = JSON.parse($store.val()); // mapping between groups and nodes

	/**
	 * update the tree to correctly display "assign node" icons
	 */
	function updateAssignNodeIcons() {
		$('.assignNodes').each(function () {
			var $icon = $(this),
				groupId = $icon.data('groupid'),
				checked = $('input[name=usergroup_chk\\[' + groupId + '\\]]').attr('checked');
			if (checked === 'checked') {
				if (nodeRestriction[groupId] && nodeRestriction[groupId].length > 0) {
					$icon.fadeTo('fast', 1.0);
				} else {
					$icon.fadeTo('fast', 0.4);
				}
			} else {
				$icon.fadeOut('fast');
			}
		});
	}
	
	/**
	 * updates the restriction object with new values
	 * updates assign node icons
	 * and writes it to the store
	 */
	function store() {
		var groupId = $('#channels').data('groupid'),
			invisible = $('#channels').data('invisible'),
			restriction = [],
			checkboxes = $('#channels li input:checked:enabled'), // find checked checkboxes
			$cb,
			i;

		for (i = 0; i < invisible.length; i++) {
			restriction.push(invisible[i]);
		}

		if (checkboxes) {
			for (i = 0; i < checkboxes.length; i++) {
				restriction.push($(checkboxes[i]).data('nodeid').toString());
			}
		}

		nodeRestriction[groupId] = restriction;
		updateAssignNodeIcons();
		
		// write data
		$store.val(JSON.stringify(nodeRestriction));
	}

	/**
	 * show the overlay dialog for a specific group
	 * 
	 * @param groupId id of the group the dialog should be shown for
	 */
	function showDialog(groupId) {
		var i,
			html = '',
			checked,
			restriction = nodeRestriction[groupId] ? nodeRestriction[groupId] : [],
			visible = [],
			invisible = [],
			folder,
			nodeId,
			invisible_i18n,
			icon;

		for (i = 0; i < folders.length; i++) {
			folder = folders[i];
			icon = settings.icoDomain;
			if (folder.type === 'channel') {
				icon = settings.icoDomainChannel;
			}
			checked = ($.inArray(folder.nodeId.toString(), restriction) === -1) ? '' : ' checked="checked"';
			visible.push(folder.nodeId.toString());
			html += '<li><input type="checkbox" ' +
				'data-nodeid="' + folder.nodeId + '"' + 
				checked +
				'> ' +
				'<img src="' + icon + '" /> ' + 
				folder.name +
				'</li>';
		}

		// also add the invisible nodes, that are "checked"
		for (i = 0; i < restriction.length; i++) {
			nodeId = restriction[i];
			if ($.inArray(nodeId, visible) === -1) {
				invisible.push(nodeId);
			}
		}

		if (invisible.length > 0) {
			invisible_i18n = invisible.length == 1 ? 'invisible_node_i18n' : 'invisible_nodes_i18n';
			html = '<li><input type="checkbox" checked="checked" disabled="disabled"> '
					+ '<img src="'
					+ settings.icoDomain
					+ '" /> <i>'
					+ invisible.length
					+ ' '
					+ $('#' + invisible_i18n).html() + '</i></li>' + html;
		}

		$('#channels').data('invisible', invisible);
		$('#channels').data('groupid', groupId).html(html);
		$('#overlay').fadeIn('fast');
	}
	
	/**
	 * hide the overlay
	 * 
	 * @param storeData {boolean} true if changes should be stored (OK) false, otherwise (Cancel)
	 */
	function hideDialog(storeData) {
		$('#overlay').fadeOut('fast');
		
		if (storeData) {
			store();
		}
	}
	
	/*
	 * initialisation
	 */
	
	// attach events
	$('.assignNodes').click(function () {
		var groupId = $(this).data('groupid');
		showDialog(groupId);
	});
	
	$('#overlayOK').click(function () {
		hideDialog(true);
	});
	
	$('#overlayCancel').click(function () {
		hideDialog(false);
	});
	
	$('div.dialog input[type=checkbox]').click(function () {
		updateAssignNodeIcons();
	});
	
	// load list of folders
	$.get('/CNPortletapp/rest/folder/getFolders/0?sid=' + settings.sid, function (data) {
		if (data.folders) {
			folders = data.folders;
		}
	});
	
	updateAssignNodeIcons();
};